--
-- Haeckselklappe
--
-- M@D Author:  Heady (Deichsel.lua)
-- @ edit by: Brndi
-- M@D date: 24.11.2010
-- @edit date: 05.02.11
--
-- > Copyright (C) Heady - www.planet-ls.de / Brndi < --
--

Haeckselklappe = {};

function Haeckselklappe.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(AnimatedVehicle, specializations);
end;

function Haeckselklappe:load(xmlFile)
	
	local klappe = {};
    klappe.name = getXMLString(xmlFile, "vehicle.klappe#name");
    klappe.openSpeedScale = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.klappe#upSpeedScale"), 1);
    klappe.closeSpeedScale = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.klappe#downSpeedScale"), -klappe.openSpeedScale);
    if klappe.name ~= nil then
        self.klappe = klappe;
    end;
	self.klappe.active = false;
	
	
	local i=0;
    while true do
        local key = string.format("vehicle.animations.animation(%d)", i);
        if not hasXMLProperty(xmlFile, key) then
            break;
        end;
        local name = getXMLString(xmlFile, key.."#name");
        if name ~= nil then		
			if name == "klappe" then			
				local partKey = key..string.format(".part(%d)", 0);
				local loadTime = getXMLFloat(xmlFile, partKey.."#loadTime");
				local endTime = getXMLFloat(xmlFile, partKey.."#endTime");
				
				local currentTime = self:getAnimationTime(self.klappe.name);
				local speed = 1;
				if currentTime > loadTime/endTime then
					speed = -1;
				end;
				self:playAnimation(self.klappe.name, speed, currentTime, true);
				self:setAnimationStopTime(self.klappe.name, loadTime/endTime);
				AnimatedVehicle.updateAnimations(self, 99999999);				
			end;
        end;
        i = i+1;
    end;
end;

function Haeckselklappe:delete()
end;

function Haeckselklappe:mouseEvent(posX, posY, isDown, isUp, button)
end;

function Haeckselklappe:keyEvent(unicode, sym, modifier, isDown)
end;

function Haeckselklappe:readStream(streamId, connection)
	local klappeAnimTime = streamReadFloat32(streamId);
	
	if klappeAnimTime ~= nil then
		local currentTime = self:getAnimationTime(self.klappe.name);
		local speed = 1;
		if currentTime > klappeAnimTime then
			speed = -1;
		end;
		self:playAnimation(self.klappe.name, speed, currentTime, true);
		self:setAnimationStopTime(self.klappe.name, klappeAnimTime);	
	end;

	AnimatedVehicle.updateAnimations(self, 50);		

end;

function Haeckselklappe:writeStream(streamId, connection)
	streamWriteFloat32(streamId, self:getAnimationTime(self.klappe.name));
end;

function Haeckselklappe:update(dt)

	if self:getIsActiveForInput() then
		
		local isKlappeActive = false;
		if InputBinding.isPressed(InputBinding.Haeckselklappe_auf) then
			isKlappeActive = true;	
			if InputBinding.hasEvent(InputBinding.Haeckselklappe_auf) then
				self:playAnimation(self.klappe.name, self.klappe.openSpeedScale, self:getAnimationTime(self.klappe.name)); 
			end;			
		elseif InputBinding.isPressed(InputBinding.Haeckselklappe_zu) then
			isKlappeActive = true;
			if InputBinding.hasEvent(InputBinding.Haeckselklappe_zu) then
				self:playAnimation(self.klappe.name, self.klappe.closeSpeedScale, self:getAnimationTime(self.klappe.name));
			end;
		end
		if self.klappe.active and not isKlappeActive then
      		self:stopAnimation(self.klappe.name);	
		end;
		self.klappe.active = isKlappeActive;
		
	end;

end;

function Haeckselklappe:updateTick(dt)
	if self:getIsActive() then
		for _, part in pairs(self.movingParts) do
			part.isDirty = true;
		end;	
	end;
end;

function Haeckselklappe:draw()	

	g_currentMission:addExtraPrintText(InputBinding.getKeyNamesOfDigitalAction(InputBinding.Haeckselklappe_auf).." / "..InputBinding.getKeyNamesOfDigitalAction(InputBinding.Haeckselklappe_zu)..": Haeckselklappe auf / zu");
	
end;
